Module api

Module api 

Structs

Assuredworkloads
Central instance to access all Assuredworkloads related resource activities
GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest
Request for acknowledging the violation
GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse
Response for violation acknowledgement
GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
Response containing the analysis results for the hypothetical resource move.
GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest
Request to apply update to a workload.
GoogleCloudAssuredworkloadsV1AssetMoveAnalysis
Represents move analysis results for an asset.
GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse
Response for EnableComplianceUpdates endpoint.
GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse
Response for EnableResourceMonitoring endpoint.
GoogleCloudAssuredworkloadsV1ListViolationsResponse
Response of ListViolations endpoint.
GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
Response of listing the compliance updates per workload with pagination.
GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
Response of ListWorkloads endpoint.
GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
Represents a logical group of checks performed for an asset. If successful, the group contains the analysis result, otherwise it contains an error with the failure reason.
GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
GoogleCloudAssuredworkloadsV1MoveImpact
Represents the impact of moving the asset to the target.
GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest
Request for updating permission settings for a partner workload.
GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule
A rule used to express this policy.
GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues
The values allowed for a ListPolicy.
GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.
GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest
Request for restricting list of available resources in Workload environment.
GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse
Response for restricting the list of allowed resources.
GoogleCloudAssuredworkloadsV1UpdateDetails
The details of the update.
GoogleCloudAssuredworkloadsV1Violation
Workload monitoring Violation.
GoogleCloudAssuredworkloadsV1ViolationExceptionContext
Violation exception detail.
GoogleCloudAssuredworkloadsV1ViolationRemediation
Represents remediation guidance to resolve compliance violation for AssuredWorkload
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions
Instructions to remediate violation
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole
Remediation instructions to resolve violation via cloud console
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
Remediation instructions to resolve violation via gcloud cli
GoogleCloudAssuredworkloadsV1Workload
A Workload object for managing highly regulated workloads of cloud customers.
GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus
Represents the Compliance Status of this workload
GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response
GoogleCloudAssuredworkloadsV1WorkloadKMSSettings
Settings specific to the Key Management Service.
GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload
GoogleCloudAssuredworkloadsV1WorkloadResourceInfo
Represent the resources that are children of this Workload.
GoogleCloudAssuredworkloadsV1WorkloadResourceSettings
Represent the custom settings for the resources to be created.
GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
GoogleCloudAssuredworkloadsV1WorkloadUpdate
A workload update is a change to the workload’s compliance configuration.
GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions
Options to be set for the given created workload.
GoogleLongrunningListOperationsResponse
The response message for Operations.ListOperations.
GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
GoogleRpcStatus
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
OrganizationLocationOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
OrganizationLocationOperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
OrganizationLocationWorkloadAnalyzeWorkloadMoveCall
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks. The analysis is best effort and is not guaranteed to be exhaustive.
OrganizationLocationWorkloadCreateCall
Creates Assured Workload.
OrganizationLocationWorkloadDeleteCall
Deletes the workload. Make sure that workload’s direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.
OrganizationLocationWorkloadEnableComplianceUpdateCall
This endpoint enables Assured Workloads service to offer compliance updates for the folder based assured workload. It sets up an Assured Workloads Service Agent, having permissions to read compliance controls (for example: Org Policies) applied on the workload. The caller must have resourcemanager.folders.getIamPolicy and resourcemanager.folders.setIamPolicy permissions on the assured workload folder.
OrganizationLocationWorkloadEnableResourceMonitoringCall
Enable resource violation monitoring for a workload.
OrganizationLocationWorkloadGetCall
Gets Assured Workload associated with a CRM Node
OrganizationLocationWorkloadListCall
Lists Assured Workloads under a CRM Node.
OrganizationLocationWorkloadMutatePartnerPermissionCall
Update the permissions settings for an existing partner workload. For force updates don’t set etag field in the Workload. Only one update operation per workload can be in progress.
OrganizationLocationWorkloadPatchCall
Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don’t set etag field in the Workload. Only one update operation per workload can be in progress.
OrganizationLocationWorkloadRestrictAllowedResourceCall
Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/assured-workloads/docs/supported-products In addition to assuredworkloads.workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.
OrganizationLocationWorkloadUpdateApplyCall
This endpoint creates a new operation to apply the given update.
OrganizationLocationWorkloadUpdateListCall
This endpoint lists all updates for the given workload.
OrganizationLocationWorkloadViolationAcknowledgeCall
Acknowledges an existing violation. By acknowledging a violation, users acknowledge the existence of a compliance violation in their workload and decide to ignore it due to a valid business justification. Acknowledgement is a permanent operation and it cannot be reverted.
OrganizationLocationWorkloadViolationGetCall
Retrieves Assured Workload Violation based on ID.
OrganizationLocationWorkloadViolationListCall
Lists the Violations in the AssuredWorkload Environment. Callers may also choose to read across multiple Workloads as per AIP-159 by using ‘-’ (the hyphen or dash character) as a wildcard character instead of workload-id in the parent. Format organizations/{org_id}/locations/{location}/workloads/-
OrganizationMethods
A builder providing access to all methods supported on organization resources. It is not used directly, but through the Assuredworkloads hub.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.