pub struct GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse {
pub asset_move_analyses: Option<Vec<GoogleCloudAssuredworkloadsV1AssetMoveAnalysis>>,
pub next_page_token: Option<String>,
}Expand description
Response containing the analysis results for the hypothetical resource move.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
asset_move_analyses: Option<Vec<GoogleCloudAssuredworkloadsV1AssetMoveAnalysis>>List of analysis results for each asset in scope.
next_page_token: Option<String>The next page token. Is empty if the last page is reached.