pub struct GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest {
pub action: Option<String>,
}Expand description
Request to apply update to a workload.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
action: Option<String>The action to be performed on the update.