pub struct GoogleCloudAssuredworkloadsV1AssetMoveAnalysis {
pub analysis_groups: Option<Vec<GoogleCloudAssuredworkloadsV1MoveAnalysisGroup>>,
pub asset: Option<String>,
pub asset_type: Option<String>,
}Expand description
Represents move analysis results for an asset.
This type is not used in any activity, and only used as part of another schema.
Fields
analysis_groups: Option<Vec<GoogleCloudAssuredworkloadsV1MoveAnalysisGroup>>List of eligible analyses performed for the asset.
asset: Option<String>The full resource name of the asset being analyzed. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1
asset_type: Option<String>Type of the asset being analyzed. Possible values will be among the ones listed here.