pub struct GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse {
pub next_page_token: Option<String>,
pub workload_updates: Option<Vec<GoogleCloudAssuredworkloadsV1WorkloadUpdate>>,
}Expand description
Response of listing the compliance updates per workload with pagination.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>The next page token. Return empty if reached the last page.
workload_updates: Option<Vec<GoogleCloudAssuredworkloadsV1WorkloadUpdate>>The list of workload updates for a given workload.