pub struct GoogleCloudAssuredworkloadsV1ListWorkloadsResponse {
pub next_page_token: Option<String>,
pub workloads: Option<Vec<GoogleCloudAssuredworkloadsV1Workload>>,
}Expand description
Response of ListWorkloads endpoint.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations workloads list organizations (response)
Fields
next_page_token: Option<String>The next page token. Return empty if reached the last page.
workloads: Option<Vec<GoogleCloudAssuredworkloadsV1Workload>>List of Workloads under a given parent.