pub struct GoogleCloudAssuredworkloadsV1MoveAnalysisGroup {
pub analysis_result: Option<GoogleCloudAssuredworkloadsV1MoveAnalysisResult>,
pub display_name: Option<String>,
pub error: Option<GoogleRpcStatus>,
}Expand description
Represents a logical group of checks performed for an asset. If successful, the group contains the analysis result, otherwise it contains an error with the failure reason.
This type is not used in any activity, and only used as part of another schema.
Fields
analysis_result: Option<GoogleCloudAssuredworkloadsV1MoveAnalysisResult>Result of a successful analysis.
display_name: Option<String>Name of the analysis group.
error: Option<GoogleRpcStatus>Error details for a failed analysis.