pub struct GoogleCloudAssuredworkloadsV1MoveAnalysisResult {
pub blockers: Option<Vec<GoogleCloudAssuredworkloadsV1MoveImpact>>,
pub warnings: Option<Vec<GoogleCloudAssuredworkloadsV1MoveImpact>>,
}Expand description
Represents the successful move analysis results for a group.
This type is not used in any activity, and only used as part of another schema.
Fields
blockers: Option<Vec<GoogleCloudAssuredworkloadsV1MoveImpact>>List of blockers. If not resolved, these will result in compliance violations in the target.
warnings: Option<Vec<GoogleCloudAssuredworkloadsV1MoveImpact>>List of warnings. These are risks that may or may not result in compliance violations.