pub struct GoogleCloudAssuredworkloadsV1MoveImpact {
pub detail: Option<String>,
}Expand description
Represents the impact of moving the asset to the target.
This type is not used in any activity, and only used as part of another schema.
Fields
detail: Option<String>Explanation of the impact.