GoogleCloudAssuredworkloadsV1OrgPolicyUpdate

Struct GoogleCloudAssuredworkloadsV1OrgPolicyUpdate 

pub struct GoogleCloudAssuredworkloadsV1OrgPolicyUpdate {
    pub applied_policy: Option<GoogleCloudAssuredworkloadsV1OrgPolicy>,
    pub suggested_policy: Option<GoogleCloudAssuredworkloadsV1OrgPolicy>,
}
Represents an update for an org policy control applied on an Assured Workload resource. The inherited org policy is not considered.

This type is not used in any activity, and only used as part of another schema.

Fields

applied_policy: Option<GoogleCloudAssuredworkloadsV1OrgPolicy>

The org policy currently applied on the assured workload resource.

suggested_policy: Option<GoogleCloudAssuredworkloadsV1OrgPolicy>

The suggested org policy that replaces the applied policy.