GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions

Struct GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions 

pub struct GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions {
    pub access_transparency_logs_support_case_viewer: Option<bool>,
    pub assured_workloads_monitoring: Option<bool>,
    pub data_logs_viewer: Option<bool>,
    pub service_access_approver: Option<bool>,
}
Permissions granted to the AW Partner SA account for the customer workload

This type is not used in any activity, and only used as part of another schema.

Fields

access_transparency_logs_support_case_viewer: Option<bool>

Optional. Allow partner to view support case details for an AXT log

assured_workloads_monitoring: Option<bool>

Optional. Allow partner to view violation alerts.

data_logs_viewer: Option<bool>

Optional. Allow the partner to view inspectability logs and monitoring violations.

service_access_approver: Option<bool>

Optional. Allow partner to view access approval logs.