pub struct GoogleCloudAssuredworkloadsV1WorkloadResourceInfo {
pub resource_id: Option<i64>,
pub resource_type: Option<String>,
}Expand description
Represent the resources that are children of this Workload.
This type is not used in any activity, and only used as part of another schema.
Fields
resource_id: Option<i64>Output only. Resource identifier. For a project this represents project_number.
resource_type: Option<String>Indicates the type of resource.