pub struct GoogleCloudAssuredworkloadsV1WorkloadResourceSettings {
pub display_name: Option<String>,
pub resource_id: Option<String>,
pub resource_type: Option<String>,
}Expand description
Represent the custom settings for the resources to be created.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>User-assigned resource display name. If not empty it will be used to create a resource with the specified name.
resource_id: Option<String>Resource identifier. For a project this represents project_id. If the project is already taken, the workload creation will fail. For KeyRing, this represents the keyring_id. For a folder, don’t set this value as folder_id is assigned by Google.
resource_type: Option<String>Indicates the type of resource. This field should be specified to correspond the id to the right project type (CONSUMER_PROJECT or ENCRYPTION_KEYS_PROJECT)