pub struct GoogleCloudAssuredworkloadsV1WorkloadUpdate {
pub create_time: Option<DateTime<Utc>>,
pub details: Option<GoogleCloudAssuredworkloadsV1UpdateDetails>,
pub name: Option<String>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A workload update is a change to the workload’s compliance configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
create_time: Option<DateTime<Utc>>The time the update was created.
details: Option<GoogleCloudAssuredworkloadsV1UpdateDetails>The details of the update.
name: Option<String>Output only. Immutable. Identifier. Resource name of the WorkloadUpdate. Format: organizations/{organization}/locations/{location}/workloads/{workload}/updates/{update}
state: Option<String>Output only. The state of the update.
update_time: Option<DateTime<Utc>>The time the update was last updated.