pub struct GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions {
pub kaj_enrollment_type: Option<String>,
}Expand description
Options to be set for the given created workload.
This type is not used in any activity, and only used as part of another schema.
Fields
kaj_enrollment_type: Option<String>Optional. Specifies type of KAJ Enrollment if provided.