pub struct OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>where
C: 'a,{ /* private fields */ }Expand description
Analyzes a hypothetical move of a source resource to a target workload to surface compliance risks. The analysis is best effort and is not guaranteed to be exhaustive.
A builder for the locations.workloads.analyzeWorkloadMove method supported by a organization resource.
It is not used directly, but through a OrganizationMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.organizations().locations_workloads_analyze_workload_move("target")
.project("sed")
.page_token("ut")
.page_size(-12)
.add_asset_types("rebum.")
.doit().await;Implementations
Sourceimpl<'a, C> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>where
C: Connector,
impl<'a, C> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>where
C: Connector,
Sourcepub async fn doit(
self,
) -> Result<(Response, GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse)>
pub async fn doit( self, ) -> Result<(Response, GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse)>
Perform the operation you have build so far.
Sourcepub fn target(
self,
new_value: &str,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn target( self, new_value: &str, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Required. The resource ID of the folder-based destination workload. This workload is where the source resource will hypothetically be moved to. Specify the workload’s relative resource name, formatted as: “organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOAD_ID}” For example: “organizations/123/locations/us-east1/workloads/assured-workload-2”
Sets the target path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
Sourcepub fn project(
self,
new_value: &str,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn project( self, new_value: &str, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
The source type is a project. Specify the project’s relative resource name, formatted as either a project number or a project ID: “projects/{PROJECT_NUMBER}” or “projects/{PROJECT_ID}” For example: “projects/951040570662” when specifying a project number, or “projects/my-project-123” when specifying a project ID.
Sets the project query property to the given value.
Sourcepub fn page_token(
self,
new_value: &str,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn page_token( self, new_value: &str, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Optional. The page token from the previous response. It needs to be passed in the second and following requests.
Sets the page token query property to the given value.
Sourcepub fn page_size(
self,
new_value: i32,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn page_size( self, new_value: i32, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Optional. Page size. If a value is not specified, the default value of 10 is used. The maximum value is 50.
Sets the page size query property to the given value.
Sourcepub fn add_asset_types(
self,
new_value: &str,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn add_asset_types( self, new_value: &str, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Optional. List of asset types to be analyzed, including and under the source resource. If empty, all assets are analyzed. The complete list of asset types is available here.
Append the given value to the asset types query property. Each appended value will retain its original ordering and be ‘/’-separated in the URL’s parameters.
Sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.Sets the delegate property to the given value.
Sourcepub fn param<T>(
self,
name: T,
value: T,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn param<T>( self, name: T, value: T, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- $.xgafv (query-string) - V1 error format.
- access_token (query-string) - OAuth access token.
- alt (query-string) - Data format for response.
- callback (query-string) - JSONP
- fields (query-string) - Selector specifying which fields to include in a partial response.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
Sourcepub fn add_scope<St>(
self,
scope: St,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn add_scope<St>( self, scope: St, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead of the default Scope variant
Scope::CloudPlatform.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.
Sourcepub fn add_scopes<I, St>(
self,
scopes: I,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn add_scopes<I, St>( self, scopes: I, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Identifies the authorization scope(s) for the method you are building.
See Self::add_scope() for details.
Sourcepub fn clear_scopes(
self,
) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
pub fn clear_scopes( self, ) -> OrganizationLocationWorkloadAnalyzeWorkloadMoveCall<'a, C>
Removes all scopes, and no default scope will be used either.
In this case, you have to specify your API-key using the key parameter (see Self::param()
for details).