pub struct GoogleCloudAssuredworkloadsV1OrgPolicy {
pub constraint: Option<String>,
pub inherit: Option<bool>,
pub reset: Option<bool>,
pub resource: Option<String>,
pub rule: Option<GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule>,
}Expand description
This assured workload service object is used to represent the org policy attached to a resource. It servces the same purpose as the orgpolicy.v2.Policy object but with functionality that is limited to what is supported by Assured Workloads(e.g. only one rule under one OrgPolicy object, no conditions, etc).
This type is not used in any activity, and only used as part of another schema.
Fields
constraint: Option<String>The constraint name of the OrgPolicy. e.g. “constraints/gcp.resourceLocations”.
inherit: Option<bool>If inherit is true, policy rules of the lowest ancestor in the resource hierarchy chain are inherited. If it is false, policy rules are not inherited.
reset: Option<bool>Ignores policies set above this resource and restores to the constraint_default value. reset can only be true when rules is empty and inherit is false.
resource: Option<String>Resource that the OrgPolicy attaches to. Format: folders/123“ projects/123“.
rule: Option<GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule>The rule of the OrgPolicy.